Learn R Programming

VCA (version 1.3.1)

fixef.VCA: Extract Fixed Effects from 'VCA' Object.

Description

Conviniently extracting the 'FixedEffects' element of an 'VCA' object.

Usage

"fixef"(object, type = c("simple", "complex"), ddfm = c("contain", "residual", "satterthwaite"), tol = 1e-12, quiet = FALSE, ...)

Arguments

object
(VCA) object where fixed effects shall be extracted
type
(character) string or partial string, specifying whether to return "simple" (reduced) or a rather "complex" (more detailed) information about fixed effects
ddfm
(character) string specifying the method used for computing the degrees of freedom of the t-statistic. Only used when type="complex". Available methods are "contain", "residual", and "satterthwaite".
tol
(numeric) value representing the numeric tolerance use in comparisons, values smaller than 'tol' will be considered equal to 0
quiet
(logical) TRUE = suppress warning messages, e.g. for non-estimable contrasts
...
additional parameters

Details

The default is to return the fixed effects estimates together with their standard errors. If setting 'type="complex"' or to an abbreviation (e.g. "c") additional inferential statistics on these estimates will be returned, i.e. "t Value", "DF" and respective p-value "Pr > |t|". One can choose one of three denominator degrees of freedom ('ddfm')-methods.

Examples

Run this code
## Not run: 
# data(dataEP05A2_1)
# fit <- anovaVCA(y~day/(run), dataEP05A2_1)
# fixef(fit)
# 
# # for complex models it might take some time computing complex output
# data(VCAdata1)
# fit <- anovaMM(y~(lot+device)/(day)/(run), VCAdata1[VCAdata1$sample==2,])
# fixef(fit, "c")
# ## End(Not run)

Run the code above in your browser using DataLab