Learn R Programming

VCA (version 1.3.1)

lmerSummary: Derive VCA-Summary Table from an object fitted via function lmer.

Description

This function builds a variance components analysis results table from an object representing a model fitted by lmer of the lme4 R-package. It applies the approximation of the variance-covariance matrix of variance components according to Giesbrecht & Burns (1985) and uses this information to approximate the degrees of freedom according to Satterthwaite (see SAS PROC MIXED documentation option 'CL').

Usage

lmerSummary(obj, VarVC = TRUE, terms = NULL, Mean = NULL, cov = FALSE, X = NULL)

Arguments

obj
(lmerMod) object as returned by function lmer
VarVC
(logical) TRUE = the variance-covariance matrix of variance components will be approximated following the Giesbrecht & Burns approach, FALSE = it will not be approximated
terms
(character) vector, optionally defining the order of variance terms to be used
Mean
(numeric) mean value used for CV-calculation
cov
(logical) TRUE = in case of non-zero covariances a block diagonal matrix will be constructed, FALSE = a diagonal matrix with all off-diagonal element being equal to zero will be contructed
X
(matrix) design matrix of fixed effects as constructed to meet VCA-package requirements

Value

(list) still a premature 'VCA' object but close to a

Details

This function is not intended to be called directly by users and therefore not exported.

References

Searle, S.R, Casella, G., McCulloch, C.E. (1992), Variance Components, Wiley New York

Giesbrecht, F.G. and Burns, J.C. (1985), Two-Stage Analysis Based on a Mixed Model: Large-Sample Asymptotic Theory and Small-Sample Simulation Results, Biometrics 41, p. 477-486

See Also

remlVCA, remlMM