vcov.VCA: Calculate Variance-Covariance Matrix of Fixed Effects for an 'VCA' Object.
Description
Return the variance-covariance matrix of fixed effects for
a linear mixed model applicable for objects of class 'VCA'.
Usage
## S3 method for class 'VCA':
vcov(object, ...)
Arguments
object
(VCA) object for which the
variance-covariance matrix of fixed effects shall be
calculated
...
additional parameters
Value
(matrix) corresponding to the variance-covariance matrix of
fixed effects
Details
Actually this function only extracts this matrix or, if not
available, calls function vcovFixed which
performs calculations. It exists for compatibility reasons,
i.e. for coneniently using objects of class 'VCA' with
other packages expecting this function, e.g. the 'multcomp'
package for general linear hypotheses for parametric
models.