lmerG: Construct Variance-Covariance Matrix of Random Effects for Models Fitted by Function 'lmer'.
Description
This function either restricts the variance-covariance matrix of random effects G to be either
diagonal ('cov=FALSE') or to take any non-zero covariances into account (default, 'cov=TRUE').
Usage
lmerG(obj, cov = FALSE)
Arguments
obj
(object) inheriting from class 'lmerMod'
cov
(logical) TRUE = in case of non-zero covariances a block diagonal matrix will be constructed,
FALSE = a diagonal matrix with all off-diagonal element being equal to zero will be contructed
Value
(Matrix) representing the variance-covariance structure of random effects G
Details
This function is not intended to be called directly by users and therefore not exported!