Learn R Programming

VCA (version 1.2.1)

print.VCA: Standard Printing Method for Objects of Class 'VCA'.

Description

Function prints 'VCA' objects as returned by function anovaVCA.

Usage

## S3 method for class 'VCA':
print(x, digits = 6L, ...)

Arguments

x
(VCA) object of class 'VCA' as returned by function 'anovaVCA'.
digits
(integer) number of digits numeric values are rounded to before printing.
...
additional arguments to be passed to or from methods.